function dsi_aviso_altimetry(varargin)
% DataSetInventory and Interface for the AVISO altimetry 
%
% Meri Sheremet
% June 2008

% modification:
% 2008/07/02 edited to place dsi_.mat file in GUI subdirectory if not
% compiled -- ceb

% DataSetBranch=function of (Satellite,TimeMode,SpatialCoverage)
List.Satellite={
% short name for programming, full name for menus;    
'Merged',   'Merged (All Available Satellites)';
'TPJ1',     'TOPEX/Poseidon-Jason 1';
'Envisat',  'Envisat (2003-2007)';
'ERS12',    'ERS-1/2 (2001-2003)';
'GFO',      'GFO (2001-2007)';
'J1',       'Jason-1 (2002-2007)';
'TP',       'TOPEX/Poseidon (2001-2005)';
};
List.TimeMode={
'DT',       'Daily - Delayed Time';
'NRT',      'Daily - Near-Real Time';
};
List.SpatialCoverage={
'M',        'Mediterranean 1/8 deg';
'NG',       'Near Global 1/3 deg';
'G1deg',    'Global 1 deg';    
'G1degWW',  'Global 1 deg Wind and Waves';
};
 %NG signifies Near Global(180W to 180E and 82S to 82N)coverage 1/3 deg
 %M indicates regional Mediterranean (5W to 36.875E and 30N to 46N) coverage 1/8 deg
 %lr 1deg low resolution
 %G 1deg
if nargin < 1 
List.DataSetBranch={    
%Satellite_TimeMode_SpatialCoverage
'Merged_DT_NG'; 
'Merged_DT_M' ;
%
'Merged_NRT_NG';
'Merged_NRT_G1deg';   
'Merged_NRT_G1degWW';   
'Merged_NRT_M'    ;
%
'TPJ1_DT_NG'     ;
%
'Envisat_NRT_NG'     ;
'Envisat_NRT_G1deg';
'Envisat_NRT_M'       ;
%
'ERS12_NRT_NG'          ;
'ERS12_NRT_G1deg'    ;
'ERS12_NRT_M'           ;
%
'GFO_NRT_NG'          ;
'GFO_NRT_G1deg'    ;
'GFO_NRT_M'           ;
%
'J1_NRT_NG'        ;
'J1_NRT_G1deg'  ;
'J1_NRT_M'         ;
%
'TP_NRT_NG'             ;
'TP_NRT_G1deg'       ;
'TP_NRT_M'              ;
};
    
    for k=1:length(List.DataSetBranch)
    disp(['DSI_' List.DataSetBranch{k} ])
    eval(['DSI_' List.DataSetBranch{k} ';'])
    end

    dsi_filename = 'dsi_aviso_altimetry.mat';
    if (~isdeployed)
        pname = mfilename('fullpath');
        pname = pname(1:length(pname) - length(mfilename));
        dsi_filename = [pname,dsi_filename];
    end
    
    if ~exist(dsi_filename,'file')
        save(dsi_filename,'List')
    else
        eval(['save ' dsi_filename ' -append List' ';'])
    end

elseif nargin > 1
    disp('Incorrect number of arguments.'); return  
else
% with one argument for the specified DataSetBranch only     
eval(varargin{1}); 
end

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON URLCDEPTH])
% constraints URLCTIME URLCLAT URLCLON URLCDEPTH can be in different order
% constraints URLCLAT URLCLON URLCDEPTH will be generated by program get



function DSI=DSI_common2(FieldsTable,DSI); 
DSI.Fields         =FieldsTable(:,1);
CoordinatesTable={
'latitude','latitude','degrees North';
'longitude','longitude','degrees East';
'time','time','days since 0000-01-01 00:00:00';
};
DSI.Coordinates=CoordinatesTable(:,1);


for k=1:length(DSI.Fields)
    FIELD=DSI.Fields{k};
eval(['DSI.Variables.' FIELD '=FieldsTable{k,6};'])
end
DSI.Variables.latitude={'latitude'};
DSI.Variables.longitude={'longitude'};
DSI.Variables.depth={'depth'};
DSI.Variables.time={'time'};

for k=1:length(DSI.Fields)
    FIELD=DSI.Fields{k};
eval(['DSI.Attributes.' FIELD '.long_name=FieldsTable{k,5};']);
    UNITS='none';
    if strcmp(FIELD,'ssh') UNITS='cm'; end
    if strcmp(FIELD,'u') UNITS='cm/s'; end
    if strcmp(FIELD,'v') UNITS='cm/s'; end
    if strcmp(FIELD,'sla') UNITS='cm'; end
    if strcmp(FIELD,'err') UNITS='%'; end
    if strcmp(FIELD,'ua') UNITS='cm/s'; end
    if strcmp(FIELD,'va') UNITS='cm/s'; end
    if strcmp(FIELD,'swh') UNITS='m'; end
    if strcmp(FIELD,'wind') UNITS='m/s'; end
eval(['DSI.Attributes.' FIELD '.units    =UNITS;']);
end
for k=1:length(DSI.Coordinates)
    COORD=DSI.Coordinates{k};
eval(['DSI.Attributes.' COORD '.long_name=CoordinatesTable{k,2};']);
eval(['DSI.Attributes.' COORD '.units    =CoordinatesTable{k,3};']);
end

for k=1:length(DSI.Fields)
    FIELD=DSI.Fields{k};
eval(['DSI.URLCVAR.' FIELD '=FieldsTable{k,3};']);
end

% Rename returned variables and change dimensions order
for k=1:length(DSI.Fields)
    FIELD=DSI.Fields{k};
    RETURNEDNAME=FieldsTable{k,4};
    FREN=['f=squeeze(' RETURNEDNAME ');'];
eval(['DSI.FormulaRen.' FIELD '=''' FREN ''';']);      
end

DSI.Dimensions.latitude=length(DSI.Latitude);
DSI.Dimensions.longitude=length(DSI.Longitude);
DSI.Dimensions.time=length(DSI.Time);


 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Merged_DT_NG 
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Merged_DT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_global_merged_madt_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:762],Grid_0001[0:1:762][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_global_merged_madt_h?
%Grid_0001[0:1:762][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_global_merged_madt_uv?
%Grid_0001[0:1:762][0:1:1079][0:1:914],Grid_0002[0:1:762][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_global_merged_msla_h?
%Grid_0001[0:1:762][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_global_merged_msla_err?
%Grid_0001[0:1:762][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_global_merged_msla_uv?
%Grid_0001[0:1:762][0:1:1079][0:1:914],Grid_0002[0:1:762][0:1:1079][0:1:914]

DSI.Satellite='Merged';
DSI.TimeMode='DT';
DSI.SpatialCoverage='NG';
DSI.TRes='7 day';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'ssh'  ,'dt_upd_global_merged_madt_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Dynamic Topography (H)'   ,LL    ,TLL    ,1;
    'u'    ,'dt_upd_global_merged_madt_uv'  ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Geostrophic Velocity (U)' ,LL    ,TLL    ,3;
    'v'    ,'dt_upd_global_merged_madt_uv'  ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Absolute Geostrophic Velocity (V)' ,LL    ,TLL    ,5;
    'sla'  ,'dt_upd_global_merged_msla_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'dt_upd_global_merged_msla_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
    'ua'   ,'dt_upd_global_merged_msla_uv'  ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Geostrophic Velocity Anomaly (U)'  ,LL    ,TLL    ,4;
    'va'   ,'dt_upd_global_merged_msla_uv'  ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Geostrophic Velocity Anomaly (V)'  ,LL    ,TLL    ,6;
     };
 
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.dTime=dt;
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;



DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Merged_DT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Merged_DT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_med_merged_madt_h?
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:762],Grid_0001[0:1:762][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_med_merged_madt_h?
%Grid_0001[0:1:762][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_med_merged_madt_uv?
%Grid_0001[0:1:762][0:1:335][0:1:128],Grid_0002[0:1:762][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_med_merged_msla_h?
%Grid_0001[0:1:762][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_med_merged_msla_err?
%Grid_0001[0:1:762][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_upd_med_merged_msla_uv?
%Grid_0001[0:1:762][0:1:335][0:1:128],Grid_0002[0:1:762][0:1:335][0:1:128]

DSI.Satellite='Merged';
DSI.TimeMode='DT';
DSI.SpatialCoverage='M';
DSI.TRes='7 day';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                name in        returned name           menu name                         opendap dataset
%    name                                   dataset                                                                   coord  coord  CBNum
    'ssh'  ,'dt_upd_med_merged_madt_h'     ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Dynamic Topography (H)'   ,LL    ,TLL    ,1;
    'u'    ,'dt_upd_med_merged_madt_uv'    ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Geostrophic Velocity (U)' ,LL    ,TLL    ,3;
    'v'    ,'dt_upd_med_merged_madt_uv'    ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Absolute Geostrophic Velocity (V)' ,LL    ,TLL    ,5;
    'sla'  ,'dt_upd_med_merged_msla_h'     ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'dt_upd_med_merged_msla_err'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
    'ua'   ,'dt_upd_med_merged_msla_uv'    ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Geostrophic Velocity Anomaly (U)'  ,LL    ,TLL    ,4;
    'va'   ,'dt_upd_med_merged_msla_uv'    ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Geostrophic Velocity Anomaly (V)'  ,LL    ,TLL    ,6;
     };
 
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_TPJ1_DT_NG   
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='TPJ1_DT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_ref_global_tpj1_msla_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:762],Grid_0001[0:1:762][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_ref_global_tpj1_msla_h?
%Grid_0001[0:1:762][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_ref_global_tpj1_msla_err?
%Grid_0001[0:1:762][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/dt_ref_global_tpj1_msla_uv?
%Grid_0001[0:1:762][0:1:1079][0:1:914],Grid_0002[0:1:762][0:1:1079][0:1:914]

DSI.Satellite='TPJ1';
DSI.TimeMode='DT';
DSI.SpatialCoverage='NG';
DSI.TRes='7 day';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in       returned name          menu name                         opendap dataset
%    name                                    dataset                                                                coord  coord  CBNum
    'sla'  ,'dt_ref_global_tpj1_msla_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001' ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'dt_ref_global_tpj1_msla_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001' ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
    'ua'   ,'dt_ref_global_tpj1_msla_uv'  ,'Grid_0001'  ,'Grid_0001.Grid_0001' ,'Geostrophic Velocity Anomaly (U)'  ,LL    ,TLL    ,4;
    'va'   ,'dt_ref_global_tpj1_msla_uv'  ,'Grid_0002'  ,'Grid_0002.Grid_0002' ,'Geostrophic Velocity Anomaly (V)'  ,LL    ,TLL    ,6;
     };
 
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Merged_NRT_NG
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Merged_NRT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_madt_merged_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:1050],Grid_0001[0:1:1050][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_madt_merged_h?
%Grid_0001[0:1:1050][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_madt_merged_uv?
%Grid_0001[0:1:1050][0:1:1079][0:1:914],Grid_0002[0:1:1050][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_merged_h?
%Grid_0001[0:1:1051][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_merged_err?
%Grid_0001[0:1:1050][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_merged_uv?
%Grid_0001[0:1:1048][0:1:1079][0:1:914],Grid_0002[0:1:1048][0:1:1079][0:1:914]

DSI.Satellite='Merged';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='NG';
DSI.TRes='daily';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                   name in        returned name           menu name                         opendap dataset
%    name                                      dataset                                                                   coord  coord  CBNum
    'ssh'  ,'duacs_global_nrt_madt_merged_h'  ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Dynamic Topography (H)'   ,LL    ,TLL    ,1;
    'u'    ,'duacs_global_nrt_madt_merged_uv' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Geostrophic Velocity (U)' ,LL    ,TLL    ,3;
    'v'    ,'duacs_global_nrt_madt_merged_uv' ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Absolute Geostrophic Velocity (V)' ,LL    ,TLL    ,5;
    'sla'  ,'duacs_global_nrt_msla_merged_h'  ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_global_nrt_msla_merged_err','Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
    'ua'   ,'duacs_global_nrt_msla_merged_uv' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Geostrophic Velocity Anomaly (U)'  ,LL    ,TLL    ,4;
    'va'   ,'dt_upd_global_merged_msla_uv'    ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Geostrophic Velocity Anomaly (V)'  ,LL    ,TLL    ,6;
     };
 
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Merged_NRT_G1deg
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Merged_NRT_G1deg';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_merged_h_lr?
%NbLatitudes[0:1:180],NbLongitudes[0:1:359],time[0:1:1047],Grid_0001[0:1:1047][0:1:359][0:1:180]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_merged_h_lr?
%NbLatitudes[0:1:180],NbLongitudes[0:1:359],time[0:1:1047],Grid_0001[0:1:1047][0:1:359][0:1:180]

DSI.Satellite='Merged';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1deg';
DSI.TRes='daily';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                       name in        returned name           menu name                         opendap dataset
%    name                                          dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_merged_h_lr'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Merged_NRT_G1degWW 
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Merged_NRT_G1degWW';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/nrt-misc_mswh_merged?
%NbLatitudes[0:1:179],NbLongitudes[0:1:359],time[0:1:850],Grid_0001[0:1:850][0:1:359][0:1:179]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/nrt-misc_mswh_merged?
%Grid_0001[0:1:850][0:1:359][0:1:179]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/nrt-misc_mwind_merged?
%Grid_0001[0:1:850][0:1:359][0:1:179]

DSI.Satellite='Merged';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1degWW';
DSI.TRes='daily';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name          menu name                  opendap dataset
%    name                                    dataset                                                           coord  coord  CBNum
    'swh'     ,'nrt-misc_mswh_merged'       ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Significant Wave Height'  ,LL    ,TLL    ,7;
    'wind'    ,'nrt-misc_mwind_merged'      ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Wind Speed '              ,LL    ,TLL    ,9;
         };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Merged_NRT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Merged_NRT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_madt_merged_h?
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:629],Grid_0001[0:1:629][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_madt_merged_h?
%Grid_0001[0:1:629][0:1:335][0:1:128] 
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_madt_merged_uv?
%Grid_0001[0:1:1005][0:1:335][0:1:128],Grid_0002[0:1:1005][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_merged_h?
%Grid_0001[0:1:1005][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_merged_err?
%Grid_0001[0:1:1006][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_merged_uv?
%Grid_0001[0:1:1006][0:1:335][0:1:128],Grid_0002[0:1:1006][0:1:335][0:1:128]

DSI.Satellite='Merged';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='M';
DSI.TRes='daily';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                         name in        returned name           menu name                         opendap dataset
%    name                                            dataset                                                                   coord  coord  CBNum
    'ssh'  ,'duacs_mediterranean_nrt_madt_merged_h'  ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Dynamic Topography (H)'   ,LL    ,TLL    ,1;
    'u'    ,'duacs_mediterranean_nrt_madt_merged_uv' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Absolute Geostrophic Velocity (U)' ,LL    ,TLL    ,3;
    'v'    ,'duacs_mediterranean_nrt_madt_merged_uv' ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Absolute Geostrophic Velocity (V)' ,LL    ,TLL    ,5;
    'sla'  ,'duacs_mediterranean_nrt_msla_merged_h'  ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_mediterranean_nrt_msla_merged_err','Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
    'ua'   ,'duacs_mediterranean_nrt_msla_merged_uv' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Geostrophic Velocity Anomaly (U)'  ,LL    ,TLL    ,4;
    'va'   ,'duacs_mediterranean_nrt_msla_merged_uv' ,'Grid_0002'  ,'Grid_0002.Grid_0002'  ,'Geostrophic Velocity Anomaly (V)'  ,LL    ,TLL    ,6;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Envisat_NRT_NG 
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Envisat_NRT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_en_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:899],Grid_0001[0:1:899][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_en_h?
%Grid_0001[0:1:899][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_en_err?
%Grid_0001[0:1:899][0:1:1079][0:1:914]

DSI.Satellite='Envisat';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='NG';
DSI.TRes='daily';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_en_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_global_nrt_msla_en_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_Envisat_NRT_G1deg  %1deg Low Resolution 
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Envisat_NRT_G1deg';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_en_h_lr?
%NbLatitudes[0:1:180],NbLongitudes[0:1:359],time[0:1:899],
%Grid_0001[0:1:899][0:1:359][0:1:180]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_en_h_lr?
%Grid_0001[0:1:899][0:1:359][0:1:180]

DSI.Satellite='Envisat';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1deg';
DSI.TRes='daily';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_en_h_lr' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function DSI=DSI_Envisat_NRT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='Envisat_NRT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_en_h
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:848],Grid_0001[0:1:848][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_en_h?
%Grid_0001[0:1:848][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_en_err?
%Grid_0001[0:1:848][0:1:335][0:1:128]

DSI.Satellite='Envisat';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='M';
DSI.TRes='daily';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                       name in        returned name           menu name                         opendap dataset
%    name                                          dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_mediterranean_nrt_msla_en_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_mediterranean_nrt_msla_en_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };
 
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_ERS12_NRT_NG 
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='ERS12_NRT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_e2_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:117],Grid_0001[0:1:117][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_e2_h?
%Grid_0001[0:1:117][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_e2_err?
%Grid_0001[0:1:117][0:1:1079][0:1:914]

DSI.Satellite='ERS12';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='NG';
DSI.TRes='7 day';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';


% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};
FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_e2_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_global_nrt_msla_e2_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function DSI=DSI_ERS12_NRT_G1deg
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='ERS12_NRT_G1deg';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_e2_h_lr?
%NbLatitudes[0:1:180],NbLongitudes[0:1:359],time[0:1:117],Grid_0001[0:1:117][0:1:359][0:1:180]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_e2_h_lr?
%Grid_0001[0:1:117][0:1:359][0:1:180]

DSI.Satellite='ERS12';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1deg';
DSI.TRes='7 day';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_e2_h_lr' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function DSI=DSI_ERS12_NRT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='ERS12_NRT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_e2_h?
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:78],Grid_0001[0:1:78][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_e2_h?
%Grid_0001[0:1:78][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_e2_err?
%Grid_0001[0:1:78][0:1:335][0:1:128]

DSI.Satellite='ERS12';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='M';
DSI.TRes='4 day';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                       name in        returned name           menu name                         opendap dataset
%    name                                          dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_mediterranean_nrt_msla_e2_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_mediterranean_nrt_msla_e2_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

% if ~exist('dsi_aviso_altimetry.mat','file')
% eval(['save dsi_aviso_altimetry.mat DSI_' DSI.DataSetBranch ';'])
% end
% eval(['save dsi_aviso_altimetry.mat -append DSI_' DSI.DataSetBranch ';'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function DSI=DSI_GFO_NRT_NG
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='GFO_NRT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_g2_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:946],Grid_0001[0:1:946][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_g2_h?
%Grid_0001[0:1:946][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_g2_err?
%Grid_0001[0:1:946][0:1:1079][0:1:914]

DSI.Satellite='GFO';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='NG';
DSI.TRes='daily';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};
FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_g2_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_global_nrt_msla_g2_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
function DSI=DSI_GFO_NRT_G1deg
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='GFO_NRT_G1deg';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_g2_h_lr?
%NbLatitudes[0:1:180],NbLongitudes[0:1:359],time[0:1:946],Grid_0001[0:1:946][0:1:359][0:1:180]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_g2_h_lr?
%Grid_0001[0:1:946][0:1:359][0:1:180]

DSI.Satellite='GFO';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1deg';
DSI.TRes='daily';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_g2_h_lr','Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
function DSI=DSI_GFO_NRT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='GFO_NRT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_g2_h?
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:820],Grid_0001[0:1:820][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_g2_h?
%Grid_0001[0:1:820][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_g2_err?
%Grid_0001[0:1:820][0:1:335][0:1:128]

DSI.Satellite='GFO';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='M';
DSI.TRes='daily';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                       name in        returned name           menu name                         opendap dataset
%    name                                          dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_mediterranean_nrt_msla_g2_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_mediterranean_nrt_msla_g2_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
function DSI=DSI_J1_NRT_NG
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='J1_NRT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_j1_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:1004],Grid_0001[0:1:1004][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_j1_h?
%Grid_0001[0:1:1004][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_j1_err?
%Grid_0001[0:1:1004][0:1:1079][0:1:914]

DSI.Satellite='J1';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='NG';
DSI.TRes='daily';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};
FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_j1_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_global_nrt_msla_j1_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
function DSI=DSI_J1_NRT_G1deg
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='J1_NRT_G1deg';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_j1_h_lr?
%NbLatitudes[0:1:180],NbLongitudes[0:1:359],time[0:1:1004],Grid_0001[0:1:1004][0:1:359][0:1:180]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_j1_h_lr?
%Grid_0001[0:1:1004][0:1:359][0:1:180]

DSI.Satellite='J1';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1deg';
DSI.TRes='daily';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_j1_h_lr' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
function DSI=DSI_J1_NRT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='J1_NRT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_j1_h?
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:991],Grid_0001[0:1:991][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_j1_h?
%Grid_0001[0:1:991][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_j1_err?
%Grid_0001[0:1:991][0:1:335][0:1:128]

DSI.Satellite='J1';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='M';
DSI.TRes='daily';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                       name in        returned name           menu name                         opendap dataset
%    name                                          dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_mediterranean_nrt_msla_j1_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_mediterranean_nrt_msla_j1_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
function DSI=DSI_TP_NRT_NG
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='TP_NRT_NG';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_tp_h?
%NbLatitudes[0:1:914],NbLongitudes[0:1:1079],time[0:1:179],Grid_0001[0:1:179][0:1:1079][0:1:914]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_tp_h?
%Grid_0001[0:1:179][0:1:1079][0:1:914]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_tp_err?
%Grid_0001[0:1:179][0:1:1079][0:1:914]

DSI.Satellite='TP';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='NG';
DSI.TRes='4 day';
DSI.HRes='1/3 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};
FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_tp_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_global_nrt_msla_tp_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };
 
DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
function DSI=DSI_TP_NRT_G1deg
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='TP_NRT_G1deg';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_tp_h_lr?
%NbLongitudes[0:1:359],time[0:1:179],Grid_0001[0:1:179][0:1:359][0:1:180]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_global_nrt_msla_tp_h_lr?
%Grid_0001[0:1:179][0:1:359][0:1:180]

DSI.Satellite='TP';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='G1deg';
DSI.TRes='4 day';
DSI.HRes='1 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                 name in        returned name           menu name                         opendap dataset
%    name                                    dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_global_nrt_msla_tp_h_lr','Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
};

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%      
function DSI=DSI_TP_NRT_M
DSI.DataSetName='AVISO_Altimetry';
DSI.DataSetBranch='TP_NRT_M';

%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_tp_h?
%NbLatitudes[0:1:128],NbLongitudes[0:1:335],time[0:1:145],Grid_0001[0:1:145][0:1:335][0:1:128]

% Examples of files in the dataset
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_tp_h?
%Grid_0001[0:1:145][0:1:335][0:1:128]
%http://opendap.aviso.oceanobs.com/thredds/dodsC/duacs_mediterranean_nrt_msla_tp_err?
%Grid_0001[0:1:145][0:1:335][0:1:128]

DSI.Satellite='TP';
DSI.TimeMode='NRT';
DSI.SpatialCoverage='M';
DSI.TRes='4 day';
DSI.HRes='1/8 deg';

DSI.URLSITE='http://opendap.aviso.oceanobs.com';
DSI.URLPATH='/thredds/dodsC/';

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','NbLongitudes','NbLatitudes'};

FieldsTable={
%    opendap       file name                       name in        returned name           menu name                         opendap dataset
%    name                                          dataset                                                                   coord  coord  CBNum
    'sla'  ,'duacs_mediterranean_nrt_msla_tp_h'   ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly (H)'             ,LL    ,TLL    ,2;
    'err'  ,'duacs_mediterranean_nrt_msla_tp_err' ,'Grid_0001'  ,'Grid_0001.Grid_0001'  ,'Sea Level Anomaly Formal Mapping Error',LL,TLL    ,8;
     };

DSI.URLFILE=FieldsTable(:,2);

DSI.Fields_NameDS  =FieldsTable(:,3);
DSI.Fields_NameReturned=FieldsTable(:,4);
DSI.Fields_NameMenu=FieldsTable(:,5);
DSI.Fields_Coord   =FieldsTable(:,6);
DSI.Fields_CoordDS =FieldsTable(:,7);
DSI.Fields_CBNum   =FieldsTable(:,8);

% ml_FillValue: 1.8447e+19 % same for all fields
DSI.FormulaNaN='f(find(f>1.0e19))=NaN;';
DSI.FormulaOrderCoord='f=f'';';

URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE{1}];
loaddap('+v',[URL '?NbLatitudes,NbLongitudes,time'])

%units: '"days since 1950-01-01"'
t0=datenum('1950-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time+t0; % in datenum days since '0000-01-01 00:00:00'
DSI.Time=t;
dt=median(diff(t));
DSI.TimeA=t-0.5*dt;
DSI.TimeB=t+0.5*dt;
DSI.dTime=dt;
DSI.Latitude=NbLatitudes;
DSI.Longitude=NbLongitudes;

DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);

DSI=DSI_common2(FieldsTable,DSI);

S1=['time in seconds since 1970-01-01 00:00:00;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])

dsi_filename = 'dsi_aviso_altimetry.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    dsi_filename = [pname,dsi_filename];
end

if ~exist(dsi_filename,'file')
    eval(['save ' dsi_filename ' DSI_' DSI.DataSetBranch ';'])
end
eval(['save ' dsi_filename ' -append DSI_' DSI.DataSetBranch ';'])